/*
ConferenceListener.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;

import androidx.annotation.Nullable;
import androidx.annotation.NonNull;

/**
* An object to handle the callbacks for the handling a LinphoneConference<br/>
* objects. <br/>
* <br/>
* Use linphone_factory_create_conference_cbs to create an instance. Then pass the<br/>
* object to a LinphoneConference instance through<br/>
* linphone_conference_add_callbacks. <br/>
*/
public interface ConferenceListener {
    /**
    * Callback used to notify a conference that a participant has been added. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param participant LinphoneParticipant that has been added to the conference   <br/>
    */
    public void onParticipantAdded(@NonNull Conference conference, @NonNull Participant participant);

    /**
    * Callback used to notify a conference that the admin status of a participant has<br/>
    * been changed. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param participant LinphoneParticipant whose admin status has changed   <br/>
    */
    public void onParticipantAdminStatusChanged(@NonNull Conference conference, @NonNull Participant participant);

    /**
    * Callback used to notify a conference that a participant has been removed. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param participant LinphoneParticipant that has been removed to the conference <br/>
    *  <br/>
    */
    public void onParticipantRemoved(@NonNull Conference conference, @NonNull Participant participant);

    /**
    * Callback used to notify a conference state has changed. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param newState The new state of the conference <br/>
    */
    public void onStateChanged(@NonNull Conference conference, Conference.State newState);

    /**
    * Callback used to notify a conference that a participant has been removed. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param participantDevice LinphoneParticipantDevice that has been removed to the<br/>
    * conference   <br/>
    */
    public void onParticipantDeviceRemoved(@NonNull Conference conference, @NonNull ParticipantDevice participantDevice);

    /**
    * Callback used to notify that the audio device of a conference has changed. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param audioDevice audio device of the conference   <br/>
    */
    public void onAudioDeviceChanged(@NonNull Conference conference, @NonNull AudioDevice audioDevice);

    /**
    * Callback used to notify that the subject of a conference has changed. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param subject subject of the conference   <br/>
    */
    public void onSubjectChanged(@NonNull Conference conference, @NonNull String subject);

    /**
    * Callback used to notify a conference that a participant has been added. <br/>
    * <br/>
    * @param conference LinphoneConference object   <br/>
    * @param participantDevice LinphoneParticipantDevice that has been added to the<br/>
    * conference   <br/>
    */
    public void onParticipantDeviceAdded(@NonNull Conference conference, @NonNull ParticipantDevice participantDevice);

}